@@ -9,7 +9,7 @@ import shutil
 from watchgod import watch
 from bloggo import hbs
 
-__version__ = "1.2.0"
+__version__ = "1.2.1"
 resources_dir = './resources'
 out_dir = './public'
 
@@ -125,45 +125,52 @@ def write(file_path, contents):
 
 
 def generate_feed(blog_path, site_config):
-    print('Generating XML feed')
     blog_paths = get_paths(blog_path)
     blog_contents = get_contents(blog_paths, site_config['site_url'])
-    template = """
-    <?xml version="1.0" encoding="UTF-8"?><rss version="2.0"
-        xmlns:content="http://purl.org/rss/1.0/modules/content/"
-        xmlns:wfw="http://wellformedweb.org/CommentAPI/"
-        xmlns:dc="http://purl.org/dc/elements/1.1/"
-        xmlns:atom="http://www.w3.org/2005/Atom"
-        xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
-        xmlns:slash="http://purl.org/rss/1.0/modules/slash/"
-        >
-    <channel>
-        <title>{{site_title}}</title>
-        <atom:link href="{{url}}/feed.xml" rel="self" type="application/rss+xml"></atom:link>
-        <link>{{site_url}}</link>
-        <description>{{site_description}}</description>
-        <lastBuildDate>Fri, 05 Feb 2021 21:41:44 +0000</lastBuildDate>
-        <language>en</language>
-        <sy:updatePeriod>hourly</sy:updatePeriod>
-        <sy:updateFrequency>1</sy:updateFrequency>
-        {{#entries}}
-        <item>
-            <title>{{title}}</title>
-            <link>{{url}}</link>
-            <pubDate>{{date}}</pubDate>
-            <description>{{description}}</description>
-            <content:encoded><![CDATA[{{{entry}}}]]></content:encoded>
-        </item>
-        {{/entries}}
-    </channel>
-    </rss>
-    """
-    compiler = pybars.Compiler()
-    compiled_template = compiler.compile(template)
-    output = compiled_template({**site_config, 'entries': blog_contents})
-    file_path = out_dir + '/feed.xml'
+    helpers = {'format_date': hbs.format_date}
 
-    write(file_path, output)
+    if len(blog_contents) > 0:
+        print("Generating XML feed")
+        template = """<?xml version="1.0" encoding="UTF-8"?><rss version="2.0"
+            xmlns:content="http://purl.org/rss/1.0/modules/content/"
+            xmlns:wfw="http://wellformedweb.org/CommentAPI/"
+            xmlns:dc="http://purl.org/dc/elements/1.1/"
+            xmlns:atom="http://www.w3.org/2005/Atom"
+            xmlns:sy="http://purl.org/rss/1.0/modules/syndication/"
+            xmlns:slash="http://purl.org/rss/1.0/modules/slash/"
+            >
+        <channel>
+            <title>{{site_title}}</title>
+            <atom:link href="{{site_url}}/feed.xml" rel="self" type="application/rss+xml"></atom:link>
+            <link>{{site_url}}</link>
+            <description>{{site_description}}</description>
+            <lastBuildDate>{{format_date last_date '%a, %d %b %Y %H:%M:%S'}} +0000</lastBuildDate>
+            <language>en</language>
+            <sy:updatePeriod>hourly</sy:updatePeriod>
+            <sy:updateFrequency>1</sy:updateFrequency>
+            {{#entries}}
+            <item>
+                <title>{{title}}</title>
+                <link>{{url}}</link>
+                <pubDate>{{format_date date '%a, %d %b %Y %H:%M:%S'}} +0000</pubDate>
+                <guid isPermaLink="false">{{url}}</guid>
+                <description>{{description}}</description>
+                <content:encoded><![CDATA[{{{entry}}}]]></content:encoded>
+            </item>
+            {{/entries}}
+        </channel>
+        </rss>
+        """
+        compiler = pybars.Compiler()
+        compiled_template = compiler.compile(template)
+        output = compiled_template({
+            **site_config,
+            'last_date': blog_contents[0]['date'],
+            'entries': blog_contents
+        }, helpers=helpers)
+        file_path = out_dir + '/feed.xml'
+
+        write(file_path, output)
 
 
 def generate_file(content, config, template, helpers):
